package TVListings::chan;

use strict;
use warnings;

use Apache::Constants qw/:http/;

use CGI qw/escapeHTML/;
use Date::Parse;
use POSIX qw/strftime/;

use TVListings::DB qw/:default SQL_CHAN_SHOWS/;
use TVListings::Config;
use TVListings::Links;

sub render {
	my ($class, $r, $q, $dbh) = @_;
	my $out = pagehead($r, $q, "TV Channel Info");
	my $cinfo = get_cinfo($dbh, $q->param('chan'));
	$out .= "<h1>" . escapeHTML($cinfo->{name});
	if ($cinfo->{icon}) {
		my ($iw, $ih) = @{$cinfo->{icon}}{qw/icn_width icn_height/};
		$out .= qq{ <img src="@{[ICONSBASE]}/$cinfo->{icon}{icn_src_file}" }
			. qq{alt="@{[escapeHTML($cinfo->{name})]}"}
			. (($iw and $ih) ? qq{ width="$iw" height="$ih"} : '')
			. '/>';
	}
	$out .= '</h1><p>'
		. "Chan ID: $cinfo->{chan}{chan_id}<br/>";
	for my $an (sort keys %{$cinfo->{atts}}) {
		$out .= "${an}s: " . join(', ', map {escapeHTML($_)}
			@{$cinfo->{atts}{$an}}) . '<br/>';
	}
	$out .= '</p>';

	my $ssth = $dbh->prepare_cached(SQL_CHAN_SHOWS);
	$ssth->execute($q->param('chan'));
	my $sres = $ssth->fetchall_arrayref({});
	
	if (@$sres) {
		$out .= qq{<table class="tvlistings">}
			. qq{<tr><th colspan="2">Channel</th><th>Show</th><th>Show Start</th>}
			. qq{<th>Show End</th></tr>\n};
	} else {
		$out .= '<i>No shows</i>';
	}

	my $chanicon = get_cicon($dbh, $q->param('chan'));
	my ($iw, $ih) = @{$chanicon}{qw/icn_width icn_height/};

	for my $row (@$sres) {
		my $icnstr = '';
		$icnstr = chanlink($r, $row->{chan_oid}, qq{<img }
			. qq{src="@{[ICONSBASE]}/$chanicon->{icn_src_file}" }
			. qq{alt="@{[escapeHTML($row->{chan_name})]}"}
			. (($iw and $ih) ? qq{ width="$iw" height="$ih"} : '')
			. '/>') . ' '
				if defined $chanicon;
		my $prgstr = prglink($r, $row->{prg_oid}, escapeHTML($row->{prg_title}));
		my $chanstr = chanlink($r, $row->{chan_oid},
			escapeHTML("$row->{chan_number} $row->{chan_name}"));
		my ($pstart, $pstop) = map {escapeHTML(strftime("%c", strptime($_)))}
			@{$row}{qw/prg_start prg_stop/};
		$out .= qq{<tr><td class="icon">$icnstr</td>}
			. qq{<td class="chan">$chanstr</td>}
			. join('', map {qq{<td class="sitem">$_</td>}} $prgstr, $pstart, $pstop)
			. "</tr>\n";
	}
	
	$out .= "</table>\n";

	$out .= pagefoot($r, $q);
	return {
		status => HTTP_OK,
		text =>$out,
	};
}

1;
